abacusai.mcp_server_query_result — AbacusAI documentation

# abacusai.mcp_server_query_result

## Classes

`McpServerQueryResult` | Result of a MCP server query

## Module Contents

class abacusai.mcp_server_query_result.McpServerQueryResult(client, output=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  Result of a MCP server query

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - output (dict) – The execution logs as well as the final output of the MCP server query

  output = None
  deprecated_keys
  __repr__()
  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict